@@ -1,3 +1,3 @@
 def func():
-    for i in range(5):
+    for _ in range(5):
         pass
